pub struct Data {
pub ptr: *const u8,
pub size: usize,
}Expand description
This is used to pass cached data back to the main thread without having to copy it
Fields
ptr: *const u8size: usizeImplementations